.. _all-salt.runners:

===========================
Full list of runner modules
===========================

.. currentmodule:: salt.runners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    cache
    cloud
    doc
    error
    fileserver
    git_pillar
    jobs
    launchd
    lxc
    manage
    mine
    network
    pillar
    queue
    search
    state
    survey
    thin
    virt
    winrepo
